@@ -1,7 +1,6 @@
 import htmlgenerator as hg
 from bread import layout as layout
 from bread.utils.urls import aslayout
-from django.contrib.auth.decorators import user_passes_test
 from django.utils.translation import gettext_lazy as _
 from dynamic_preferences.forms import global_preference_form_builder
 
@@ -56,9 +55,3 @@ def personsettings(request):
 @aslayout
 def relationshipssettings(request):
     return settings_layout.relationshipssettings(request)
-
-
-@user_passes_test(lambda user: user.is_superuser)
-@aslayout
-def maintenancesettings(request):
-    return settings_layout.maintenancesettings(request)
