@@ -8,7 +8,7 @@ from django.shortcuts import get_object_or_404
 from django.utils.translation import gettext_lazy as _
 
 from basxconnect.core import models
-from basxconnect.core.layouts import editperson
+from basxconnect.core.layouts.editperson.common.utils import tile_with_icon
 from basxconnect.core.models import Person
 from basxconnect.mailer_integration.models import Interest
 
@@ -19,14 +19,14 @@ C = bread.layout.grid.Col
 def mailer_integration_tile(request):
     person = get_object_or_404(Person, pk=request.resolver_match.kwargs["pk"])
     addresses = person.core_email_list.all()
-    return editperson.tile_with_icon(
+    return tile_with_icon(
         Icon("email--new"),
         hg.H4(
             _("Email Subscriptions"),
         ),
         *[_display_preferences(email) for email in addresses]
         if hasattr(person, "core_email_list") and person.core_email_list.count() > 0
-        else C("Person has no email addresses"),
+        else C(_("Person has no email addresses")),
     )
 
 
@@ -56,6 +56,10 @@ def _display_preferences(email):
                     onclick="return false;",
                     style="margin-left: 1rem;",
                 ),
+                hg.SPAN(
+                    mailingpreferences.get_language_display(),
+                    style="padding-left:0.5rem;",
+                ),
                 style="margin-bottom: 1.5rem;",
             ),
         ),
@@ -79,9 +83,9 @@ def _display_email_without_preferences(email):
     modal_add = modal_add_mailingpreferences(email)
     return hg.BaseElement(
         hg.DIV(email.email, style="font-weight: bold;"),
-        hg.DIV(_("no mailing preferences yet for "), email.email),
+        hg.DIV(_("No subscription yet for "), email.email),
         layout.button.Button(
-            _("Add mailing preferences"),
+            _("Add subscription"),
             buttontype="ghost",
             icon="add",
             **modal_add.openerattributes,
@@ -114,7 +118,7 @@ def is_interested_indicator(is_subscribed):
 
 def modal_edit_mailingpreferences(mailingpreferences):
     modal = layout.modal.Modal.with_ajax_content(
-        heading=_("Edit Email Subscriptions"),
+        heading=_("Edit subscription"),
         url=reverse(
             "basxconnect.mailer_integration.views.editmailingpreferencesview",
             kwargs={"pk": mailingpreferences.pk},
@@ -129,7 +133,7 @@ def modal_edit_mailingpreferences(mailingpreferences):
 
 def modal_add_mailingpreferences(email: models.Email):
     ret = layout.modal.Modal.with_ajax_content(
-        heading=_("Add Mailing Preferences"),
+        heading=_("Add subscription"),
         url=reverse(
             "basxconnect.mailer_integration.views.addmailingpreferencesview",
             query={"asajax": True, "email": email.pk, "status": "subscribed"},
